@@ -766,8 +766,14 @@ var app = window.Yancy = new Vue({
             ).fail(
                 function ( jqXHR, textStatus, errorThrown ) {
                     if ( jqXHR.responseJSON ) {
-                        self.parseErrorResponse( jqXHR.responseJSON );
-                        self.$set( self.error, 'saveItem', 'Data validation failed' );
+                        if ( jqXHR.status == 400 ) {
+                            self.parseErrorResponse( jqXHR.responseJSON );
+                            self.$set( self.error, 'saveItem', Yancy.i18n['Data validation failed'] );
+                        }
+                        else {
+                            self.$set( self.error, 'details', jqXHR.responseJSON.errors[0].message );
+                            self.$set( self.error, 'saveItem', Yancy.i18n['Internal server error'] );
+                        }
                     }
                     else {
                         self.$set( self.error, 'saveItem', jqXHR.responseText );
@@ -801,8 +807,14 @@ var app = window.Yancy = new Vue({
             ).fail(
                 function ( jqXHR, textStatus, errorThrown ) {
                     if ( jqXHR.responseJSON ) {
-                        self.parseErrorResponse( jqXHR.responseJSON );
-                        self.$set( self.error, 'addItem', 'Data validation failed' );
+                        if ( jqXHR.status == 400 ) {
+                            self.parseErrorResponse( jqXHR.responseJSON );
+                            self.$set( self.error, 'addItem', Yancy.i18n['Data validation failed'] );
+                        }
+                        else {
+                            self.$set( self.error, 'details', jqXHR.responseJSON.errors[0].message );
+                            self.$set( self.error, 'addItem', Yancy.i18n['Internal server error'] );
+                        }
                     }
                     else {
                         self.$set( self.error, 'addItem', jqXHR.responseText );
@@ -811,6 +823,10 @@ var app = window.Yancy = new Vue({
             );
         },
 
+        /**
+         * Parse the 400 Bad Request response to determine exactly which
+         * fields have errors so they can be highlighted for the user.
+         */
         parseErrorResponse: function ( resp ) {
             for ( var i = 0; i < resp.errors.length; i++ ) {
                 var error = resp.errors[ i ],
@@ -922,10 +938,16 @@ var app = window.Yancy = new Vue({
             return value;
         },
 
+        /**
+         * Produce a text ID that can be used to label the table row
+         * (for finding the row later)
+         */
         rowId: function ( row ) {
             var schema = this.currentSchema,
                 idField = schema['x-id-field'] || 'id',
-                rowId = row[ idField ];
+                rowId = Array.isArray( idField )
+                    ? idField.map( function ( idField ) { return row[idField] } ).join("::")
+                    : row[ idField ];
             return rowId;
         },
 
